Eugene-commits
Threads by month
- ----- 2026 -----
- June
- May
- April
- March
- February
- January
- ----- 2025 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2024 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2023 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2022 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2021 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2020 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2019 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2018 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2017 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2016 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2015 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2014 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2013 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2012 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2011 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2010 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2009 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2008 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2007 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2006 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2005 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2004 -----
- December
- November
- October
- September
- August
May 2012
- 3 participants
- 10 discussions
r1151 - in trunk/eugene/src/main/java/org/nuiton/eugene: java models/object models/object/xml
by athimel@users.nuiton.org 31 May '12
by athimel@users.nuiton.org 31 May '12
31 May '12
Author: athimel
Date: 2012-05-31 16:58:52 +0200 (Thu, 31 May 2012)
New Revision: 1151
Url: http://nuiton.org/repositories/revision/eugene/1151
Log:
Add ObjectModelModifier.TRANSIENT
Modified:
trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java
trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelAttribute.java
trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelBuilder.java
trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelModifier.java
trunk/eugene/src/main/java/org/nuiton/eugene/models/object/xml/ObjectModelAttributeImpl.java
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -428,6 +428,9 @@
if (attribute.isFinal()) {
modifiers.add(ObjectModelModifier.FINAL);
}
+ if (attribute.isTransient()) {
+ modifiers.add(ObjectModelModifier.TRANSIENT);
+ }
if (attribute.getVisibility().equals("public")) {
modifiers.add(ObjectModelModifier.PUBLIC);
} else if (attribute.getVisibility().equals("protected")) {
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -396,11 +396,13 @@
String attrType = GeneratorUtil.getSimpleName(attr.getType());
String attrStatic = attr.isStatic() ? "static " : "";
String attrFinal = attr.isFinal() ? "final " : "";
+ String attrTransient = attr.isTransient() ? "transient " : "";
if (clazz instanceof ObjectModelInterface) {
//tchemit 20100507 no modifier for constants in interfaces
+ attrStatic = "";
attrFinal = "";
- attrStatic = "";
+ attrTransient = "";
attrVisibility = "";
}
@@ -415,7 +417,7 @@
" = " + attr.getDefaultValue() : "";
// " = " + GeneratorUtil.getSimpleName(attr.getDefaultValue()) : "";
-/*{<%=prefix%> <%=attrVisibility%><%=attrStatic%><%=attrFinal%><%=attrType%> <%=attrName%><%=attrValue%>;
+/*{<%=prefix%> <%=attrVisibility%><%=attrStatic%><%=attrFinal%><%=attrTransient%><%=attrType%> <%=attrName%><%=attrValue%>;
}*/
}
}
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelAttribute.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelAttribute.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelAttribute.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -124,6 +124,10 @@
*/
boolean isFinal();
/**
+ * @return {@code true} if this attribute is transient.
+ */
+ boolean isTransient();
+ /**
* @return {@code true} if this attribute is navigable.
*/
boolean isNavigable();
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelBuilder.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelModifier.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelModifier.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -41,6 +41,7 @@
STATIC("static"),
FINAL("final"),
ABSTRACT("abstract"),
+ TRANSIENT("transient"),
PUBLIC("public"),
PROTECTED("protected"),
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/models/object/xml/ObjectModelAttributeImpl.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/models/object/xml/ObjectModelAttributeImpl.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/models/object/xml/ObjectModelAttributeImpl.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -60,6 +60,7 @@
protected String associationClassName;
protected boolean isStatic;
protected boolean isFinal;
+ protected boolean isTransient;
protected boolean navigable = true;
public ObjectModelAttributeImpl() {
@@ -93,6 +94,10 @@
this.isFinal = isFinal;
}
+ public void setTransient(boolean isTransient) {
+ this.isTransient = isTransient;
+ }
+
public void setStatic(boolean isStatic) {
this.isStatic = isStatic;
}
@@ -242,6 +247,10 @@
return isFinal;
}
+ public boolean isTransient() {
+ return isTransient;
+ }
+
@Override
public boolean isNavigable() {
return navigable;
1
0
Author: tchemit
Date: 2012-05-28 12:13:34 +0200 (Mon, 28 May 2012)
New Revision: 1150
Url: http://nuiton.org/repositories/revision/eugene/1150
Log:
fixes #2111: Rename m-eugene-p to eugene-m-p + fixes some documentations
Added:
trunk/eugene-maven-plugin/src/site/fr/rst/example.rst.vm
trunk/eugene-maven-plugin/src/site/rst/example.rst.vm
trunk/src/site/fr/rst/05-execution.rst.vm
trunk/src/site/rst/05-execution.rst.vm
Removed:
trunk/eugene-maven-plugin/src/site/fr/rst/example.rst
trunk/eugene-maven-plugin/src/site/rst/example.rst
trunk/src/site/fr/rst/05-execution.rst
trunk/src/site/rst/05-execution.rst
Modified:
trunk/eugene-maven-plugin/pom.xml
trunk/eugene-maven-plugin/src/it/evol-308/pom.xml
trunk/eugene-maven-plugin/src/it/evol-879/model/README.txt
trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/pom.xml
trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
trunk/eugene-maven-plugin/src/it/evol-879/xmi/README.txt
trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/pom.xml
trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
trunk/eugene-maven-plugin/src/it/evol-879/zargo/README.txt
trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/pom.xml
trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithNoProtocol/pom.xml
trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithOnlyProtocol/pom.xml
trunk/eugene-maven-plugin/src/it/smart-generate/all/pom.xml
trunk/eugene-maven-plugin/src/it/smart-generate/generators/pom.xml
trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo-xmi/pom.xml
trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo/pom.xml
trunk/eugene-maven-plugin/src/site/fr/rst/index.rst
trunk/eugene-maven-plugin/src/site/rst/index.rst
trunk/eugene/src/site/fr/rst/index.rst
trunk/pom.xml
trunk/src/site/fr/rst/03-generation.rst
trunk/src/site/fr/rst/08-FAQ.rst
trunk/src/site/fr/rst/eugene-plan.rst
trunk/src/site/fr/rst/index.rst
trunk/src/site/rst/03-generation.rst
trunk/src/site/rst/08-FAQ.rst
trunk/src/site/rst/index.rst
trunk/src/site/site_en.xml
trunk/src/site/site_fr.xml
Modified: trunk/eugene/src/site/fr/rst/index.rst
===================================================================
--- trunk/eugene/src/site/fr/rst/index.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene/src/site/fr/rst/index.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -86,5 +86,5 @@
------------
Un plugin maven est disponnible à l'adresse suivante
-http://maven-site.nuiton.org/eugene/maven-eugene-plugin . Il permet l'utilisation
+http://maven-site.nuiton.org/eugene/eugene-maven-plugin . Il permet l'utilisation
depuis maven de Eugene.
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -37,7 +37,7 @@
</parent>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<!-- POM Relationships : Inheritance : Dependencies -->
<dependencies>
@@ -192,13 +192,18 @@
<!--Site report's plugin-->
<plugin>
<artifactId>maven-plugin-plugin</artifactId>
- <version>2.5.1</version>
+ <version>${pluginPluginVersion}</version>
</plugin>
<plugin>
+ <artifactId>maven-invoker-plugin</artifactId>
+ <version>${invokerPluginVersion}</version>
+ </plugin>
+
+ <plugin>
<groupId>org.codehaus.plexus</groupId>
<artifactId>plexus-maven-plugin</artifactId>
- <version>1.3.8</version>
+ <version>${plexusPluginVersion}</version>
</plugin>
</plugins>
</reporting>
Modified: trunk/eugene-maven-plugin/src/it/evol-308/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-308/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-308/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -64,7 +64,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<fullPackagePath>org.nuiton.euegne.test</fullPackagePath>
Modified: trunk/eugene-maven-plugin/src/it/evol-879/model/README.txt
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/model/README.txt 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/model/README.txt 2012-05-28 10:13:34 UTC (rev 1150)
@@ -2,7 +2,7 @@
Le résultat désiré est :
-maven-eugene-plugin/target/its/evol-879/model/model-impl/target/
+eugene-maven-plugin/target/its/evol-879/model/model-impl/target/
|-- extracted-sources1
| `-- model
| `-- models
Modified: trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -74,7 +74,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<fullPackagePath>org.nuiton.topia</fullPackagePath>
Modified: trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/model/model-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 10:13:34 UTC (rev 1150)
@@ -77,7 +77,7 @@
// <extractDirectory>target/extracted-sources1</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/model/model-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/model/model-impl/target/
// |-- extracted-sources1
// | `-- model
// | `-- models
@@ -109,7 +109,7 @@
// <extractDirectory>target/extracted-sources2</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/model/model-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/model/model-impl/target/
// |-- extracted-sources2
// | `-- model
// | `-- models2
@@ -140,7 +140,7 @@
// <extractDirectory>target/extracted-sources3</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/model/model-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/model/model-impl/target/
// |-- extracted-sources3
// | `-- model
// | `-- topiatest3.objectmodel
@@ -167,7 +167,7 @@
// <outputDirectory>target/generated-sources4</outputDirectory>
// <extractDirectory>target/extracted-sources4</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/model/model-impl/target/
+// eugene-maven-plugin/target/its/evol-879/model/model-impl/target/
// |-- extracted-sources4
// `-- generated-sources4
// `-- java
Modified: trunk/eugene-maven-plugin/src/it/evol-879/xmi/README.txt
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/xmi/README.txt 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/xmi/README.txt 2012-05-28 10:13:34 UTC (rev 1150)
@@ -2,7 +2,7 @@
Le result désiré est :
-maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
|-- extracted-sources1
| `-- xmi
| `-- xmi
Modified: trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -59,7 +59,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<fullPackagePath>org.nuiton.topia.test.entities</fullPackagePath>
Modified: trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/xmi/xmi-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 10:13:34 UTC (rev 1150)
@@ -76,7 +76,7 @@
// <extractDirectory>target/extracted-sources1</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources1
// | `-- xmi
// | `-- xmi
@@ -108,7 +108,7 @@
// <extractDirectory>target/extracted-sources2</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources2
// | `-- xmi
// | `-- xmi
@@ -141,7 +141,7 @@
// <extractDirectory>target/extracted-sources3</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources3
// | `-- xmi
// | `-- xmi2
@@ -172,7 +172,7 @@
// <extractDirectory>target/extracted-sources4</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources4
// | `-- xmi
// | `-- xmi2
@@ -202,7 +202,7 @@
// <extractDirectory>target/extracted-sources5</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources5
// | `-- xmi
// | `-- topiatest3.xmi
@@ -230,7 +230,7 @@
// <extractDirectory>target/extracted-sources6</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources6
// | `-- xmi
// | `-- topiatest3.xmi
@@ -257,7 +257,7 @@
// <extractDirectory>target/extracted-sources7</extractDirectory>
// </configuration>
- // maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+ // eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// `-- generated-sources7
// `-- models
// |-- topiatest4.objectmodel
@@ -279,7 +279,7 @@
// <extractDirectory>target/extracted-sources8</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources8
// | `-- xmi
// | |-- topiatest3.xmi
@@ -322,7 +322,7 @@
// <extractDirectory>target/extracted-sources9</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/xmi/xmi-impl/target/
+// eugene-maven-plugin/target/its/evol-879/xmi/xmi-impl/target/
// |-- extracted-sources9
// | `-- zargo
// | |-- topiatest3.zargo
Modified: trunk/eugene-maven-plugin/src/it/evol-879/zargo/README.txt
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/zargo/README.txt 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/zargo/README.txt 2012-05-28 10:13:34 UTC (rev 1150)
@@ -2,7 +2,7 @@
Le result doit être
-maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
|-- extracted-sources
| `-- zargo
| `-- xmi
Modified: trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -59,7 +59,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<fullPackagePath>org.nuiton.topia.test.entities</fullPackagePath>
Modified: trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java
===================================================================
--- trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/evol-879/zargo/zargo-impl/src/test/java/org/nuiton/eugne/plugin/GenerationTest.java 2012-05-28 10:13:34 UTC (rev 1150)
@@ -76,7 +76,7 @@
// <extractDirectory>target/extracted-sources1</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources1
// | `-- zargo
// | `-- xmi
@@ -114,7 +114,7 @@
// <extractDirectory>target/extracted-sources</extractDirectory>
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources2
// | `-- zargo
// | `-- xmi
@@ -152,7 +152,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources3
// | `-- zargo
// | `-- xmi2
@@ -188,7 +188,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources4
// | `-- zargo
// | `-- xmi2
@@ -223,7 +223,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources5
// | `-- zargo
// | `-- topiatest3.zargo
@@ -254,7 +254,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources6
// | `-- zargo
// | `-- topiatest3.zargo
@@ -286,7 +286,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// `-- generated-sources7
// |-- models
// | |-- topiatest4.objectmodel
@@ -314,7 +314,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources8
// | `-- zargo
// | |-- topiatest3.zargo
@@ -370,7 +370,7 @@
// </configuration>
-// maven-eugene-plugin/target/its/evol-879/zargo/zargo-impl/target/
+// eugene-maven-plugin/target/its/evol-879/zargo/zargo-impl/target/
// |-- extracted-sources9
// | `-- zargo
// | |-- topiatest3.zargo
Modified: trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithNoProtocol/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithNoProtocol/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithNoProtocol/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -82,7 +82,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<executions>
<execution>
Modified: trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithOnlyProtocol/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithOnlyProtocol/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/generate-model-files/testIncludeWithOnlyProtocol/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -82,7 +82,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<executions>
<execution>
Modified: trunk/eugene-maven-plugin/src/it/smart-generate/all/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/smart-generate/all/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/smart-generate/all/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -78,7 +78,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${project.version}</version>
<configuration>
<verbose>true</verbose>
Modified: trunk/eugene-maven-plugin/src/it/smart-generate/generators/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/smart-generate/generators/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/smart-generate/generators/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -110,7 +110,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${project.version}</version>
<configuration>
<testPhase>true</testPhase>
Modified: trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -83,7 +83,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<skipInputs>xmi,model</skipInputs>
Modified: trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo-xmi/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo-xmi/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/it/smart-generate/only-zargo-xmi/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -82,7 +82,7 @@
<plugin>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
+ <artifactId>eugene-maven-plugin</artifactId>
<version>${eugeneVersion}</version>
<configuration>
<skipInputs>model</skipInputs>
Deleted: trunk/eugene-maven-plugin/src/site/fr/rst/example.rst
===================================================================
--- trunk/eugene-maven-plugin/src/site/fr/rst/example.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/site/fr/rst/example.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -1,167 +0,0 @@
-.. -
-.. * #%L
-.. * EUGene :: Maven plugin
-.. *
-.. * $Id$
-.. * $HeadURL$
-.. * %%
-.. * Copyright (C) 2006 - 2010 CodeLutin
-.. * %%
-.. * This program is free software: you can redistribute it and/or modify
-.. * it under the terms of the GNU Lesser General Public License as
-.. * published by the Free Software Foundation, either version 3 of the
-.. * License, or (at your option) any later version.
-.. *
-.. * This program is distributed in the hope that it will be useful,
-.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
-.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-.. * GNU General Lesser Public License for more details.
-.. *
-.. * You should have received a copy of the GNU General Lesser Public
-.. * License along with this program. If not, see
-.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
-.. * #L%
-.. -
-Examples
-========
-
-
-:Authors: Jean Couteau
-:Contact: couteau(a)codelutin.com
-:Revision: $Revision$
-:Date: $Date$
-
-
-.. contents::
-
-Cette page regroupe deux examples de configuration/utilisation du plugin
-dans un pom. Le premier example est très simple, le second est plus complexe
-et est censé ammener une complète compréhension du plugin combiné à la
-documentation des usages_ .
-
-.. _usages: usage.html
-
-Example simple
---------------
-
-Cet exemple va générer les entitées du package org.nuiton.eugene.demopackage à
-partir des fichiers zargo présents dans le répertoire src/main/xmi.
-
-::
-
- <plugin>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
-
- <executions>
-
- <execution>
- <phase>generate-sources</phase>
- <!-- By default, generation from ObjectModel -->
- <configuration>
- <!-- Corresponding to extracted package from zargo file -->
- <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
- <!-- DefaultPackage used for DAOHelper generation -->
- <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
- <!-- Use topia templates -->
- <templates>
- org.nuiton.topia.generator.TopiaMetaTransformer,
- org.nuiton.topia.generator.InterfaceTransformer,
- org.nuiton.topia.generator.BeanTransformer
- </templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
- </executions>
- <-- dependency to topia to use their template -->
- <dependencies>
- <dependency>
- <groupId>org.nuiton.topia</groupId>
- <artifactId>topia-persistence</artifactId>
- </dependency>
- </dependencies>
- </plugin>
-
-Example complexe
-----------------
-
-Cet exemple utilise deux fichiers zargo en entrée et va les générer différemment.
-
-Les deux premières phases sont communes, ensuite on distingues deux executions,
-une par fichier spécifiant les différents templates à utiliser pour chaque
-fichier model.
-
-::
-
- <plugin>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
- <configuration>
- <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
- <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
- </configuration>
-
- <executions>
-
- <!-- Execution that transforms zargo files to objectmodel by using
- the full run without the model phase -->
- <execution>
- <phase>generate-sources</phase>
- <id>toModel</id>
- <configuration>
- <inputs>zargo</inputs>
- <resolver>org.nuiton.util.FasterCachedResourceResolver</resolver>
- <skipInputs>model</skipInputs>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- <-- Execution that transforms the entities.objectmodel file using
- specific templates from topia -->
- <execution>
- <phase>generate-sources</phase>
- <id>model-to-entities</id>
- <configuration>
- <inputs>model:target/generated-sources/models:entities.objectmodel</inputs>
- <templates>
- org.nuiton.topia.generator.TopiaMetaTransformer,
- org.nuiton.topia.generator.InterfaceTransformer
- </templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- <-- Execution that transforms the beans.objectmodel file using
- other specific templates from topia -->
- <execution>
- <phase>generate-sources</phase>
- <id>model-to-bean</id>
- <configuration>
- <inputs>
- <input>model:target/generated-sources/models:beans.objectmodel</input>
- </inputs>
- <templates>org.nuiton.topia.generator.BeanTransformer</templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- </executions>
-
- <!-- dependency to use topia templates -->
- <dependencies>
- <dependency>
- <groupId>org.nuiton.topia</groupId>
- <artifactId>topia-persistence</artifactId>
- <version>${topiaVersion}</version>
- <scope>compile</scope>
- </dependency>
- </dependencies>
- </plugin>
Copied: trunk/eugene-maven-plugin/src/site/fr/rst/example.rst.vm (from rev 1149, trunk/eugene-maven-plugin/src/site/fr/rst/example.rst)
===================================================================
--- trunk/eugene-maven-plugin/src/site/fr/rst/example.rst.vm (rev 0)
+++ trunk/eugene-maven-plugin/src/site/fr/rst/example.rst.vm 2012-05-28 10:13:34 UTC (rev 1150)
@@ -0,0 +1,168 @@
+.. -
+.. * #%L
+.. * EUGene :: Maven plugin
+.. *
+.. * $Id$
+.. * $HeadURL$
+.. * %%
+.. * Copyright (C) 2006 - 2010 CodeLutin
+.. * %%
+.. * This program is free software: you can redistribute it and/or modify
+.. * it under the terms of the GNU Lesser General Public License as
+.. * published by the Free Software Foundation, either version 3 of the
+.. * License, or (at your option) any later version.
+.. *
+.. * This program is distributed in the hope that it will be useful,
+.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
+.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+.. * GNU General Lesser Public License for more details.
+.. *
+.. * You should have received a copy of the GNU General Lesser Public
+.. * License along with this program. If not, see
+.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+.. * #L%
+.. -
+Examples
+========
+
+
+:Authors: Jean Couteau
+:Contact: couteau(a)codelutin.com
+:Revision: $Revision$
+:Date: $Date$
+
+
+.. contents::
+
+Cette page regroupe deux examples de configuration/utilisation du plugin
+dans un pom. Le premier example est très simple, le second est plus complexe
+et est censé ammener une complète compréhension du plugin combiné à la
+documentation des usages_ .
+
+.. _usages: usage.html
+
+Example simple
+--------------
+
+Cet exemple va générer les entitées du package org.nuiton.eugene.demopackage à
+partir des fichiers zargo présents dans le répertoire src/main/xmi.
+
+::
+
+ <plugin>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-maven-plugin</artifactId>
+
+ <executions>
+
+ <execution>
+ <phase>generate-sources</phase>
+ <!-- By default, generation from ObjectModel -->
+ <configuration>
+ <!-- Corresponding to extracted package from zargo file -->
+ <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
+ <!-- DefaultPackage used for DAOHelper generation -->
+ <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
+ <!-- Use topia templates -->
+ <templates>
+ org.nuiton.topia.generator.TopiaMetaTransformer,
+ org.nuiton.topia.generator.InterfaceTransformer,
+ org.nuiton.topia.generator.BeanTransformer
+ </templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+ </executions>
+ <-- dependency to topia to use their template -->
+ <dependencies>
+ <dependency>
+ <groupId>org.nuiton.topia</groupId>
+ <artifactId>topia-persistence</artifactId>
+ </dependency>
+ </dependencies>
+ </plugin>
+
+Example complexe
+----------------
+
+Cet exemple utilise deux fichiers zargo en entrée et va les générer différemment.
+
+Les deux premières phases sont communes, ensuite on distingues deux executions,
+une par fichier spécifiant les différents templates à utiliser pour chaque
+fichier model.
+
+::
+
+ <plugin>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-maven-plugin</artifactId>
+ <version>${project.version}</version>
+ <configuration>
+ <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
+ <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
+ </configuration>
+
+ <executions>
+
+ <!-- Execution that transforms zargo files to objectmodel by using
+ the full run without the model phase -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>toModel</id>
+ <configuration>
+ <inputs>zargo</inputs>
+ <resolver>org.nuiton.util.FasterCachedResourceResolver</resolver>
+ <skipInputs>model</skipInputs>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ <-- Execution that transforms the entities.objectmodel file using
+ specific templates from topia -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>model-to-entities</id>
+ <configuration>
+ <inputs>model:target/generated-sources/models:entities.objectmodel</inputs>
+ <templates>
+ org.nuiton.topia.generator.TopiaMetaTransformer,
+ org.nuiton.topia.generator.InterfaceTransformer
+ </templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ <-- Execution that transforms the beans.objectmodel file using
+ other specific templates from topia -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>model-to-bean</id>
+ <configuration>
+ <inputs>
+ <input>model:target/generated-sources/models:beans.objectmodel</input>
+ </inputs>
+ <templates>org.nuiton.topia.generator.BeanTransformer</templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ </executions>
+
+ <!-- dependency to use topia templates -->
+ <dependencies>
+ <dependency>
+ <groupId>org.nuiton.topia</groupId>
+ <artifactId>topia-persistence</artifactId>
+ <version>${topiaVersion}</version>
+ <scope>compile</scope>
+ </dependency>
+ </dependencies>
+ </plugin>
Property changes on: trunk/eugene-maven-plugin/src/site/fr/rst/example.rst.vm
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/eugene-maven-plugin/src/site/fr/rst/index.rst
===================================================================
(Binary files differ)
Deleted: trunk/eugene-maven-plugin/src/site/rst/example.rst
===================================================================
--- trunk/eugene-maven-plugin/src/site/rst/example.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/eugene-maven-plugin/src/site/rst/example.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -1,169 +0,0 @@
-.. -
-.. * #%L
-.. * EUGene :: Maven plugin
-.. *
-.. * $Id$
-.. * $HeadURL$
-.. * %%
-.. * Copyright (C) 2006 - 2010 CodeLutin
-.. * %%
-.. * This program is free software: you can redistribute it and/or modify
-.. * it under the terms of the GNU Lesser General Public License as
-.. * published by the Free Software Foundation, either version 3 of the
-.. * License, or (at your option) any later version.
-.. *
-.. * This program is distributed in the hope that it will be useful,
-.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
-.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-.. * GNU General Lesser Public License for more details.
-.. *
-.. * You should have received a copy of the GNU General Lesser Public
-.. * License along with this program. If not, see
-.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
-.. * #L%
-.. -
-Examples
-========
-
-:Authors: Jean Couteau
-:Contact: couteau(a)codelutin.com
-:Revision: $Revision$
-:Date: $Date$
-
-.. contents::
-
-This page groups two plugin configuration/usage examples in a pom. The first
-example is very simple, the second is more complex and aimed to bring a better
-understanding of the plugin combined with the usages_ documentation.
-
-Cette page regroupe deux examples de configuration/utilisation du plugin
-dans un pom. Le premier example est très simple, le second est plus complexe
-et est censé ammener une complète compréhension du plugin combiné à la
-documentation des usages_ .
-
-.. _usages: usage.html
-
-Simple example
---------------
-
-This example will generate the entities and interfaces from the package
-org.nuiton.eugene.demopackage from the zargo files present in the src/main/xmi
-directory.
-
-::
-
- <plugin>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
-
- <executions>
-
- <execution>
- <phase>generate-sources</phase>
- <!-- By default, generation from ObjectModel -->
- <configuration>
- <!-- Corresponding to extracted package from zargo file -->
- <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
- <!-- DefaultPackage used for DAOHelper generation -->
- <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
- <!-- Use topia templates -->
- <templates>
- org.nuiton.topia.generator.TopiaMetaTransformer,
- org.nuiton.topia.generator.InterfaceTransformer,
- org.nuiton.topia.generator.BeanTransformer
- </templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
- </executions>
- <-- dependency to topia to use their template -->
- <dependencies>
- <dependency>
- <groupId>org.nuiton.topia</groupId>
- <artifactId>topia-persistence</artifactId>
- </dependency>
- </dependencies>
- </plugin>
-
-Complex example
----------------
-
-This example uses two zargo files as input and will generate them separately.
-
-The two first phases are common, then two executions are configured, one per
-file, specificating the different templates to use for each model file.
-
-::
-
- <plugin>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>maven-eugene-plugin</artifactId>
- <configuration>
- <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
- <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
- </configuration>
-
- <executions>
-
- <!-- Execution that transforms zargo files to objectmodel by using
- the full run without the model phase -->
- <execution>
- <phase>generate-sources</phase>
- <id>toModel</id>
- <configuration>
- <inputs>zargo</inputs>
- <resolver>org.nuiton.util.FasterCachedResourceResolver</resolver>
- <skipInputs>model</skipInputs>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- <-- Execution that transforms the entities.objectmodel file using
- specific templates from topia -->
- <execution>
- <phase>generate-sources</phase>
- <id>model-to-entities</id>
- <configuration>
- <inputs>model:target/generated-sources/models:entities.objectmodel</inputs>
- <templates>
- org.nuiton.topia.generator.TopiaMetaTransformer,
- org.nuiton.topia.generator.InterfaceTransformer
- </templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- <-- Execution that transforms the beans.objectmodel file using
- other specific templates from topia -->
- <execution>
- <phase>generate-sources</phase>
- <id>model-to-bean</id>
- <configuration>
- <inputs>
- <input>model:target/generated-sources/models:beans.objectmodel</input>
- </inputs>
- <templates>org.nuiton.topia.generator.BeanTransformer</templates>
- </configuration>
- <goals>
- <goal>smart-generate</goal>
- </goals>
- </execution>
-
- </executions>
-
- <!-- dependency to use topia templates -->
- <dependencies>
- <dependency>
- <groupId>org.nuiton.topia</groupId>
- <artifactId>topia-persistence</artifactId>
- <version>${topiaVersion}</version>
- <scope>compile</scope>
- </dependency>
- </dependencies>
- </plugin>
Copied: trunk/eugene-maven-plugin/src/site/rst/example.rst.vm (from rev 1149, trunk/eugene-maven-plugin/src/site/rst/example.rst)
===================================================================
--- trunk/eugene-maven-plugin/src/site/rst/example.rst.vm (rev 0)
+++ trunk/eugene-maven-plugin/src/site/rst/example.rst.vm 2012-05-28 10:13:34 UTC (rev 1150)
@@ -0,0 +1,170 @@
+.. -
+.. * #%L
+.. * EUGene :: Maven plugin
+.. *
+.. * $Id$
+.. * $HeadURL$
+.. * %%
+.. * Copyright (C) 2006 - 2010 CodeLutin
+.. * %%
+.. * This program is free software: you can redistribute it and/or modify
+.. * it under the terms of the GNU Lesser General Public License as
+.. * published by the Free Software Foundation, either version 3 of the
+.. * License, or (at your option) any later version.
+.. *
+.. * This program is distributed in the hope that it will be useful,
+.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
+.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+.. * GNU General Lesser Public License for more details.
+.. *
+.. * You should have received a copy of the GNU General Lesser Public
+.. * License along with this program. If not, see
+.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+.. * #L%
+.. -
+Examples
+========
+
+:Authors: Jean Couteau
+:Contact: couteau(a)codelutin.com
+:Revision: $Revision$
+:Date: $Date$
+
+.. contents::
+
+This page groups two plugin configuration/usage examples in a pom. The first
+example is very simple, the second is more complex and aimed to bring a better
+understanding of the plugin combined with the usages_ documentation.
+
+Cette page regroupe deux examples de configuration/utilisation du plugin
+dans un pom. Le premier example est très simple, le second est plus complexe
+et est censé ammener une complète compréhension du plugin combiné à la
+documentation des usages_ .
+
+.. _usages: usage.html
+
+Simple example
+--------------
+
+This example will generate the entities and interfaces from the package
+org.nuiton.eugene.demopackage from the zargo files present in the src/main/xmi
+directory.
+
+::
+
+ <plugin>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-maven-plugin</artifactId>
+
+ <executions>
+
+ <execution>
+ <phase>generate-sources</phase>
+ <!-- By default, generation from ObjectModel -->
+ <configuration>
+ <!-- Corresponding to extracted package from zargo file -->
+ <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
+ <!-- DefaultPackage used for DAOHelper generation -->
+ <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
+ <!-- Use topia templates -->
+ <templates>
+ org.nuiton.topia.generator.TopiaMetaTransformer,
+ org.nuiton.topia.generator.InterfaceTransformer,
+ org.nuiton.topia.generator.BeanTransformer
+ </templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+ </executions>
+ <-- dependency to topia to use their template -->
+ <dependencies>
+ <dependency>
+ <groupId>org.nuiton.topia</groupId>
+ <artifactId>topia-persistence</artifactId>
+ </dependency>
+ </dependencies>
+ </plugin>
+
+Complex example
+---------------
+
+This example uses two zargo files as input and will generate them separately.
+
+The two first phases are common, then two executions are configured, one per
+file, specificating the different templates to use for each model file.
+
+::
+
+ <plugin>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-maven-plugin</artifactId>
+ <version>${project.version}</version>
+ <configuration>
+ <defaultPackage>org.nuiton.eugene.demopackage</defaultPackage>
+ <fullPackagePath>org.nuiton.eugene.demopackage</fullPackagePath>
+ </configuration>
+
+ <executions>
+
+ <!-- Execution that transforms zargo files to objectmodel by using
+ the full run without the model phase -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>toModel</id>
+ <configuration>
+ <inputs>zargo</inputs>
+ <resolver>org.nuiton.util.FasterCachedResourceResolver</resolver>
+ <skipInputs>model</skipInputs>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ <-- Execution that transforms the entities.objectmodel file using
+ specific templates from topia -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>model-to-entities</id>
+ <configuration>
+ <inputs>model:target/generated-sources/models:entities.objectmodel</inputs>
+ <templates>
+ org.nuiton.topia.generator.TopiaMetaTransformer,
+ org.nuiton.topia.generator.InterfaceTransformer
+ </templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ <-- Execution that transforms the beans.objectmodel file using
+ other specific templates from topia -->
+ <execution>
+ <phase>generate-sources</phase>
+ <id>model-to-bean</id>
+ <configuration>
+ <inputs>
+ <input>model:target/generated-sources/models:beans.objectmodel</input>
+ </inputs>
+ <templates>org.nuiton.topia.generator.BeanTransformer</templates>
+ </configuration>
+ <goals>
+ <goal>smart-generate</goal>
+ </goals>
+ </execution>
+
+ </executions>
+
+ <!-- dependency to use topia templates -->
+ <dependencies>
+ <dependency>
+ <groupId>org.nuiton.topia</groupId>
+ <artifactId>topia-persistence</artifactId>
+ <version>${topiaVersion}</version>
+ <scope>compile</scope>
+ </dependency>
+ </dependencies>
+ </plugin>
Property changes on: trunk/eugene-maven-plugin/src/site/rst/example.rst.vm
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/eugene-maven-plugin/src/site/rst/index.rst
===================================================================
(Binary files differ)
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/pom.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -42,7 +42,7 @@
<modules>
<module>eugene</module>
- <module>maven-eugene-plugin</module>
+ <module>eugene-maven-plugin</module>
<module>ant-eugene-task</module>
</modules>
Modified: trunk/src/site/fr/rst/03-generation.rst
===================================================================
--- trunk/src/site/fr/rst/03-generation.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/fr/rst/03-generation.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -115,7 +115,7 @@
ImportsManager, AnnotationManager, ...) et le builder (pour Java : JavaBuilder).
Il est conseillé d'utiliser maven pour `executer`_ la génération en utilisant le
-`maven-eugene-plugin`_ . La configuration du plugin permet de préciser les
+`eugene-maven-plugin`_ . La configuration du plugin permet de préciser les
différents éléments de la génération (writer, reader, model, template, ...).
.. _ObjectModel: 02-objectmodel.html
@@ -127,4 +127,4 @@
.. _extensions: 06-fonctionnalites-avancees.html#Extensions
.. _executer: 05-execution.html
-.. _maven-eugene-plugin: ../maven-eugene-plugin/fr/index.html
+.. _eugene-maven-plugin: ../eugene-maven-plugin/fr/index.html
Deleted: trunk/src/site/fr/rst/05-execution.rst
===================================================================
--- trunk/src/site/fr/rst/05-execution.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/fr/rst/05-execution.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -1,62 +0,0 @@
-.. -
-.. * #%L
-.. * EUGene
-.. *
-.. * $Id$
-.. * $HeadURL$
-.. * %%
-.. * Copyright (C) 2004 - 2010 CodeLutin
-.. * %%
-.. * This program is free software: you can redistribute it and/or modify
-.. * it under the terms of the GNU Lesser General Public License as
-.. * published by the Free Software Foundation, either version 3 of the
-.. * License, or (at your option) any later version.
-.. *
-.. * This program is distributed in the hope that it will be useful,
-.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
-.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-.. * GNU General Lesser Public License for more details.
-.. *
-.. * You should have received a copy of the GNU General Lesser Public
-.. * License along with this program. If not, see
-.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
-.. * #L%
-.. -
-Execution
-=========
-
-:Author: Florian Desbois
-:Contact: eugene-devel(a)list.nuiton.org ou eugene-users(a)list.nuiton.org
-:Revision: $Revision$
-:Date: $Date$
-
-Pour mettre en oeuvre la génération en utilisant EUGene, il est possible
-d'utiliser les principaux utilitaires de build : `Ant`_ et `Maven`_
-
-Ant
----
-
-Consultez la documentation dans le `module ant`_.
-
-Maven
------
-
-Tout d'abord il vous faut la dépendance d'EUGene pour pouvoir utiliser son
-API ::
-
- <dependency>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>eugene</artifactId>
- <version>${eugeneVersion}</version>
- <scope>provided</scope>
- </dependency>
-
-A noter que le scope provided suffit, étant donné qu'EUGene n'est utilisé
-qu'à la compilation/génération.
-
-Vous pouvez désormais étendre les Transformer et Generator désirés pour
-pouvoir générer des fichiers en utilisant le plugin maven. Voir `les exemples
-et la documentation du plugin`_ .
-
-.. _les exemples et la documentation du plugin: ../maven-eugene-plugin/fr/example.html
-.. _module ant: ../ant-eugene-task/fr/
Copied: trunk/src/site/fr/rst/05-execution.rst.vm (from rev 1149, trunk/src/site/fr/rst/05-execution.rst)
===================================================================
--- trunk/src/site/fr/rst/05-execution.rst.vm (rev 0)
+++ trunk/src/site/fr/rst/05-execution.rst.vm 2012-05-28 10:13:34 UTC (rev 1150)
@@ -0,0 +1,62 @@
+.. -
+.. * #%L
+.. * EUGene
+.. *
+.. * $Id$
+.. * $HeadURL$
+.. * %%
+.. * Copyright (C) 2004 - 2010 CodeLutin
+.. * %%
+.. * This program is free software: you can redistribute it and/or modify
+.. * it under the terms of the GNU Lesser General Public License as
+.. * published by the Free Software Foundation, either version 3 of the
+.. * License, or (at your option) any later version.
+.. *
+.. * This program is distributed in the hope that it will be useful,
+.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
+.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+.. * GNU General Lesser Public License for more details.
+.. *
+.. * You should have received a copy of the GNU General Lesser Public
+.. * License along with this program. If not, see
+.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+.. * #L%
+.. -
+Execution
+=========
+
+:Author: Florian Desbois
+:Contact: eugene-devel(a)list.nuiton.org ou eugene-users(a)list.nuiton.org
+:Revision: $Revision$
+:Date: $Date$
+
+Pour mettre en oeuvre la génération en utilisant EUGene, il est possible
+d'utiliser les principaux utilitaires de build : `Ant`_ et `Maven`_
+
+Ant
+---
+
+Consultez la documentation dans le `module ant`_.
+
+Maven
+-----
+
+Tout d'abord il vous faut la dépendance d'EUGene pour pouvoir utiliser son
+API ::
+
+ <dependency>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene</artifactId>
+ <version>${project.version}</version>
+ <scope>provided</scope>
+ </dependency>
+
+A noter que le scope provided suffit, étant donné qu'EUGene n'est utilisé
+qu'à la compilation/génération.
+
+Vous pouvez désormais étendre les Transformer et Generator désirés pour
+pouvoir générer des fichiers en utilisant le plugin maven. Voir `les exemples
+et la documentation du plugin`_ .
+
+.. _les exemples et la documentation du plugin: ../eugene-maven-plugin/fr/example.html
+.. _module ant: ../ant-eugene-task/fr/
Property changes on: trunk/src/site/fr/rst/05-execution.rst.vm
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/src/site/fr/rst/08-FAQ.rst
===================================================================
--- trunk/src/site/fr/rst/08-FAQ.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/fr/rst/08-FAQ.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -74,10 +74,10 @@
Java (utilisation en tant que superclasse du Transformer
ObjectModelTransformerToJava ou du Generator ObjectModelGenerator).
Vous trouverez également quelques exemples dans les tests d'intégration du
-`maven-eugene-plugin`_ : répertoire **src/it/smart-generate**.
+`eugene-maven-plugin`_ : répertoire **src/it/smart-generate**.
.. _ToPIA: http://nuiton.org/projects/show/topia
-.. _maven-eugene-plugin: ../maven-eugene-plugin/fr/index.html
+.. _eugene-maven-plugin: ../eugene-maven-plugin/fr/index.html
Pourquoi la génération ne marche plus après renommage des fichiers .zargo et properties
=======================================================================================
Modified: trunk/src/site/fr/rst/eugene-plan.rst
===================================================================
--- trunk/src/site/fr/rst/eugene-plan.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/fr/rst/eugene-plan.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -160,7 +160,7 @@
Ressource : tchemit?
-- Documentation existante : maven-eugene-plugin
+- Documentation existante : eugene-maven-plugin
6- Fonctionnalités avancées
---------------------------
Modified: trunk/src/site/fr/rst/index.rst
===================================================================
--- trunk/src/site/fr/rst/index.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/fr/rst/index.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -54,11 +54,11 @@
* `eugene-api`_
* `ant-eugene-task`_
- * `maven-eugene-plugin`_
+ * `eugene-maven-plugin`_
.. _eugene-api: ../eugene/fr/index.html
.. _ant-eugene-task: ../ant-eugene-task/fr/index.html
-.. _maven-eugene-plugin: ../maven-eugene-plugin/fr/index.html
+.. _eugene-maven-plugin: ../eugene-maven-plugin/fr/index.html
Plus d'infos sur le projet sur la `forge nuiton`_ .
Modified: trunk/src/site/rst/03-generation.rst
===================================================================
--- trunk/src/site/rst/03-generation.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/rst/03-generation.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -111,7 +111,7 @@
builder (for Java : JavaBuilder).
Is is mainly advised to use Maven to `execute`_ generation using
-`maven-eugene-plugin`_ . Plugin configuration allows to precise the different
+`eugene-maven-plugin`_ . Plugin configuration allows to precise the different
generation elements (writer, reader, model, template, ...).
.. _ObjectModel: 02-objectmodel.html
@@ -123,4 +123,4 @@
.. _extensions: 06-fonctionnalites-avancees.html#Extensions
.. _execute: 05-execution.html
-.. _maven-eugene-plugin: maven-eugene-plugin/index.html
+.. _eugene-maven-plugin: eugene-maven-plugin/index.html
Deleted: trunk/src/site/rst/05-execution.rst
===================================================================
--- trunk/src/site/rst/05-execution.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/rst/05-execution.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -1,61 +0,0 @@
-.. -
-.. * #%L
-.. * EUGene
-.. *
-.. * $Id$
-.. * $HeadURL$
-.. * %%
-.. * Copyright (C) 2004 - 2011 CodeLutin, Chatellier Eric
-.. * %%
-.. * This program is free software: you can redistribute it and/or modify
-.. * it under the terms of the GNU Lesser General Public License as
-.. * published by the Free Software Foundation, either version 3 of the
-.. * License, or (at your option) any later version.
-.. *
-.. * This program is distributed in the hope that it will be useful,
-.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
-.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-.. * GNU General Lesser Public License for more details.
-.. *
-.. * You should have received a copy of the GNU General Lesser Public
-.. * License along with this program. If not, see
-.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
-.. * #L%
-.. -
-=========
-Execution
-=========
-
-:Author: Florian Desbois, Jean Couteau
-:Contact: eugene-devel(a)list.nuiton.org or eugene-users(a)list.nuiton.org
-:Revision: $Revision$
-:Date: $Date$
-
-To put into place generation using EUGene, it is possible to use main
-build utilities : `Ant`_ and `Maven`_
-
-Ant
----
-
-See documentation in `ant module`_.
-
-Maven
------
-
-First, you need EUGene dependency to be able to use its API ::
-
- <dependency>
- <groupId>org.nuiton.eugene</groupId>
- <artifactId>eugene</artifactId>
- <version>${eugeneVersion}</version>
- <scope>provided</scope>
- </dependency>
-
-It has to be noted that the provided scope is enough as EUGene is used only
-during compile/generation.
-
-You can now extends wanted Transformer and Generator to be able to generate
-files using the maven plugin. See `plugin documentation and examples`_ .
-
-.. _plugin documentation and examples: maven-eugene-plugin/example.html
-.. _ant module: ant-eugene-task/
Copied: trunk/src/site/rst/05-execution.rst.vm (from rev 1149, trunk/src/site/rst/05-execution.rst)
===================================================================
--- trunk/src/site/rst/05-execution.rst.vm (rev 0)
+++ trunk/src/site/rst/05-execution.rst.vm 2012-05-28 10:13:34 UTC (rev 1150)
@@ -0,0 +1,61 @@
+.. -
+.. * #%L
+.. * EUGene
+.. *
+.. * $Id$
+.. * $HeadURL$
+.. * %%
+.. * Copyright (C) 2004 - 2011 CodeLutin, Chatellier Eric
+.. * %%
+.. * This program is free software: you can redistribute it and/or modify
+.. * it under the terms of the GNU Lesser General Public License as
+.. * published by the Free Software Foundation, either version 3 of the
+.. * License, or (at your option) any later version.
+.. *
+.. * This program is distributed in the hope that it will be useful,
+.. * but WITHOUT ANY WARRANTY; without even the implied warranty of
+.. * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+.. * GNU General Lesser Public License for more details.
+.. *
+.. * You should have received a copy of the GNU General Lesser Public
+.. * License along with this program. If not, see
+.. * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+.. * #L%
+.. -
+=========
+Execution
+=========
+
+:Author: Florian Desbois, Jean Couteau
+:Contact: eugene-devel(a)list.nuiton.org or eugene-users(a)list.nuiton.org
+:Revision: $Revision$
+:Date: $Date$
+
+To put into place generation using EUGene, it is possible to use main
+build utilities : `Ant`_ and `Maven`_
+
+Ant
+---
+
+See documentation in `ant module`_.
+
+Maven
+-----
+
+First, you need EUGene dependency to be able to use its API ::
+
+ <dependency>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene</artifactId>
+ <version>${project.version}</version>
+ <scope>provided</scope>
+ </dependency>
+
+It has to be noted that the provided scope is enough as EUGene is used only
+during compile/generation.
+
+You can now extends wanted Transformer and Generator to be able to generate
+files using the maven plugin. See `plugin documentation and examples`_ .
+
+.. _plugin documentation and examples: eugene-maven-plugin/example.html
+.. _ant module: ant-eugene-task/
Property changes on: trunk/src/site/rst/05-execution.rst.vm
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/src/site/rst/08-FAQ.rst
===================================================================
--- trunk/src/site/rst/08-FAQ.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/rst/08-FAQ.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -77,10 +77,10 @@
(ToPIA-persistence module) lots of examples of Transformer and/or Generator for
Java code generation (uses ObjectModelTransformerToJava or ObjectModelGenerator
as superclass). You can also find some examples of integration tests of
-`maven-eugene-plugin`_ : directory **src/it/smart-generate**.
+`eugene-maven-plugin`_ : directory **src/it/smart-generate**.
.. _ToPIA: http://nuiton.org/projects/show/topia
-.. _maven-eugene-plugin: maven-eugene-plugin/index.html
+.. _eugene-maven-plugin: eugene-maven-plugin/index.html
Why properties are not taken during generation after renomming .zargo file ?
============================================================================
Modified: trunk/src/site/rst/index.rst
===================================================================
--- trunk/src/site/rst/index.rst 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/rst/index.rst 2012-05-28 10:13:34 UTC (rev 1150)
@@ -54,11 +54,11 @@
* `eugene-api`_
* `ant-eugene-task`_
- * `maven-eugene-plugin`_
+ * `eugene-maven-plugin`_
.. _eugene-api: eugene/index.html
.. _ant-eugene-task: ant-eugene-task/index.html
-.. _maven-eugene-plugin: maven-eugene-plugin/index.html
+.. _eugene-maven-plugin: eugene-maven-plugin/index.html
More info on the project on `nuiton's forge`_ .
Modified: trunk/src/site/site_en.xml
===================================================================
--- trunk/src/site/site_en.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/site_en.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -68,6 +68,8 @@
</breadcrumbs>
<links>
+ <item name="Nuiton.org" href="http://nuiton.org"/>
+ <item name="Code Lutin" href="http://www.codelutin.com"/>
<item name="Libre-Entreprise" href="http://www.libre-entreprise.org/" />
</links>
Modified: trunk/src/site/site_fr.xml
===================================================================
--- trunk/src/site/site_fr.xml 2012-05-28 09:25:56 UTC (rev 1149)
+++ trunk/src/site/site_fr.xml 2012-05-28 10:13:34 UTC (rev 1150)
@@ -68,6 +68,8 @@
</breadcrumbs>
<links>
+ <item name="Nuiton.org" href="http://nuiton.org"/>
+ <item name="Code Lutin" href="http://www.codelutin.com"/>
<item name="Libre-Entreprise" href="http://www.libre-entreprise.org/"/>
</links>
@@ -99,12 +101,12 @@
</menu>
<!-- TC-20100117 does not works on none primary language -->
- <!--<menu ref="modules"/>-->
- <menu name="Modules">
- <item name="Eugene :: Eugene" href="../eugene/fr/index.html"/>
- <item name="Eugene :: Ant task" href="../ant-eugene-task/fr/index.html"/>
- <item name="Eugene :: Maven plugin" href="../maven-eugene-plugin/fr/index.html"/>
- </menu>
+ <menu ref="modules"/>
+ <!--<menu name="Modules">-->
+ <!--<item name="Eugene :: Eugene" href="../eugene/fr/index.html"/>-->
+ <!--<item name="Eugene :: Ant task" href="../ant-eugene-task/fr/index.html"/>-->
+ <!--<item name="Eugene :: Maven plugin" href="../eugene-maven-plugin/fr/index.html"/>-->
+ <!--</menu>-->
<menu ref="reports"/>
1
0
Author: tchemit
Date: 2012-05-28 11:25:56 +0200 (Mon, 28 May 2012)
New Revision: 1149
Url: http://nuiton.org/repositories/revision/eugene/1149
Log:
refs #2111: Rename m-eugene-p to eugene-m-p
Added:
trunk/eugene-maven-plugin/
Removed:
trunk/maven-eugene-plugin/
Property changes on: trunk/eugene-maven-plugin
___________________________________________________________________
Added: svn:ignore
+ target
*.iml
*.ipr
*.iws
.settings
.classpath
.project
Added: svn:mergeinfo
+ /branches/1.0.1-Javabuilder/maven-eugene-plugin:641-651
/branches/1.1.0-Javabuilder/maven-eugene-plugin:652-681
/branches/eugene-2.0/maven-eugene-plugin:682-754
1
0
r1148 - in trunk: . ant-eugene-task/src/site eugene eugene/src/site maven-eugene-plugin/src/site src/site
by tchemit@users.nuiton.org 28 May '12
by tchemit@users.nuiton.org 28 May '12
28 May '12
Author: tchemit
Date: 2012-05-28 11:19:29 +0200 (Mon, 28 May 2012)
New Revision: 1148
Url: http://nuiton.org/repositories/revision/eugene/1148
Log:
fix logos links
fix scmwebeditor urls
reformat pom
move exclusions to parent pom
Modified:
trunk/ant-eugene-task/src/site/site_en.xml
trunk/ant-eugene-task/src/site/site_fr.xml
trunk/eugene/pom.xml
trunk/eugene/src/site/site_en.xml
trunk/eugene/src/site/site_fr.xml
trunk/maven-eugene-plugin/src/site/site_en.xml
trunk/maven-eugene-plugin/src/site/site_fr.xml
trunk/pom.xml
trunk/src/site/site_en.xml
trunk/src/site/site_fr.xml
Modified: trunk/ant-eugene-task/src/site/site_en.xml
===================================================================
--- trunk/ant-eugene-task/src/site/site_en.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/ant-eugene-task/src/site/site_en.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -80,7 +80,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/ant-eugene-task/src/site/site_fr.xml
===================================================================
--- trunk/ant-eugene-task/src/site/site_fr.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/ant-eugene-task/src/site/site_fr.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -84,7 +84,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/eugene/pom.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -98,16 +98,6 @@
<dependency>
<groupId>jaxen</groupId>
<artifactId>jaxen</artifactId>
- <exclusions>
- <exclusion>
- <groupId>maven-plugins</groupId>
- <artifactId>maven-cobertura-plugin</artifactId>
- </exclusion>
- <exclusion>
- <groupId>maven-plugins</groupId>
- <artifactId>maven-findbugs-plugin</artifactId>
- </exclusion>
- </exclusions>
</dependency>
<!-- Meta model uml d'eclipse -->
Modified: trunk/eugene/src/site/site_en.xml
===================================================================
--- trunk/eugene/src/site/site_en.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/eugene/src/site/site_en.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -81,7 +81,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/eugene/src/site/site_fr.xml
===================================================================
--- trunk/eugene/src/site/site_fr.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/eugene/src/site/site_fr.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -93,7 +93,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/maven-eugene-plugin/src/site/site_en.xml
===================================================================
--- trunk/maven-eugene-plugin/src/site/site_en.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/maven-eugene-plugin/src/site/site_en.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -80,7 +80,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/maven-eugene-plugin/src/site/site_fr.xml
===================================================================
--- trunk/maven-eugene-plugin/src/site/site_fr.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/maven-eugene-plugin/src/site/site_fr.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -84,7 +84,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/pom.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -22,7 +22,9 @@
<http://www.gnu.org/licenses/lgpl-3.0.html>.
#L%
-->
-<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
+<project xmlns="http://maven.apache.org/POM/4.0.0"
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
<modelVersion>4.0.0</modelVersion>
@@ -133,6 +135,14 @@
<groupId>xalan</groupId>
<artifactId>xalan</artifactId>
</exclusion>
+ <exclusion>
+ <groupId>maven-plugins</groupId>
+ <artifactId>maven-cobertura-plugin</artifactId>
+ </exclusion>
+ <exclusion>
+ <groupId>maven-plugins</groupId>
+ <artifactId>maven-findbugs-plugin</artifactId>
+ </exclusion>
</exclusions>
</dependency>
@@ -392,10 +402,10 @@
<extensions>
<extension>
<groupId>org.apache.maven.wagon</groupId>
- <artifactId>wagon-ssh-external</artifactId>
- <version>1.0</version>
+ <artifactId>wagon-ssh-external</artifactId>
+ <version>1.0</version>
</extension>
-
+
</extensions>
<pluginManagement>
<plugins>
@@ -510,12 +520,14 @@
<phase>pre-site</phase>
<configuration>
<tasks>
- <copy todir="target/site/xsd/v1" verbose="${maven.verbose}" failonerror="false" overwrite="true">
+ <copy todir="target/site/xsd/v1" verbose="${maven.verbose}"
+ failonerror="false" overwrite="true">
<fileset dir="${basedir}/eugene/src/main/resources/xsd">
<include name="**/*.xsd"/>
</fileset>
</copy>
- <copy todir="target/site/dtd/v1" verbose="${maven.verbose}" failonerror="false" overwrite="true">
+ <copy todir="target/site/dtd/v1" verbose="${maven.verbose}"
+ failonerror="false" overwrite="true">
<fileset dir="${basedir}/eugene/src/main/resources/dtd">
<include name="**/*.dtd"/>
</fileset>
Modified: trunk/src/site/site_en.xml
===================================================================
--- trunk/src/site/site_en.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/src/site/site_en.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -57,8 +57,8 @@
<poweredBy>
<logo href="http://maven.apache.org" name="Maven" img="${project.url}/images/logos/maven-feather.png"/>
- <logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/jrst-logo.png"/>
- <logo href="http://docutils.sourceforge.net/rst.html" name="ReStructuredText" img="${project.url}/images/restructuredtext-logo.png"/>
+ <logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/logos/jrst-logo.png"/>
+ <logo href="http://docutils.sourceforge.net/rst.html" name="ReStructuredText" img="${project.url}/images/logos/restructuredtext-logo.png"/>
</poweredBy>
<body>
@@ -112,7 +112,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
Modified: trunk/src/site/site_fr.xml
===================================================================
--- trunk/src/site/site_fr.xml 2012-05-28 09:05:31 UTC (rev 1147)
+++ trunk/src/site/site_fr.xml 2012-05-28 09:19:29 UTC (rev 1148)
@@ -57,8 +57,8 @@
<poweredBy>
<logo href="http://maven.apache.org" name="Maven" img="${project.url}/images/logos/maven-feather.png"/>
- <logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/jrst-logo.png"/>
- <logo href="http://docutils.sourceforge.net/rst.html" name="ReStructuredText" img="${project.url}/images/restructuredtext-logo.png"/>
+ <logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/logos/jrst-logo.png"/>
+ <logo href="http://docutils.sourceforge.net/rst.html" name="ReStructuredText" img="${project.url}/images/logos/restructuredtext-logo.png"/>
</poweredBy>
<body>
@@ -118,7 +118,7 @@
projectversion='${project.version}'
platform='${project.platform}'
projectid='${project.projectId}'
- scm='${project.scm.url}'
+ scm='${project.scm.connection}'
scmwebeditorenabled='${project.scmwebeditorEnabled}'
scmwebeditorurl='${project.scmwebeditorUrl}'
siteSourcesType='${project.siteSourcesType}'
1
0
Author: tchemit
Date: 2012-05-28 11:05:31 +0200 (Mon, 28 May 2012)
New Revision: 1147
Url: http://nuiton.org/repositories/revision/eugene/1147
Log:
fix jaxen dependencies
Modified:
trunk/eugene/pom.xml
trunk/eugene/src/license/THIRD-PARTY.properties
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2012-05-28 08:48:30 UTC (rev 1146)
+++ trunk/eugene/pom.xml 2012-05-28 09:05:31 UTC (rev 1147)
@@ -94,10 +94,20 @@
<scope>runtime</scope>
</dependency>
- <!-- dom4j dep -->
+ <!-- jaxen dep -->
<dependency>
<groupId>jaxen</groupId>
<artifactId>jaxen</artifactId>
+ <exclusions>
+ <exclusion>
+ <groupId>maven-plugins</groupId>
+ <artifactId>maven-cobertura-plugin</artifactId>
+ </exclusion>
+ <exclusion>
+ <groupId>maven-plugins</groupId>
+ <artifactId>maven-findbugs-plugin</artifactId>
+ </exclusion>
+ </exclusions>
</dependency>
<!-- Meta model uml d'eclipse -->
Modified: trunk/eugene/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene/src/license/THIRD-PARTY.properties 2012-05-28 08:48:30 UTC (rev 1146)
+++ trunk/eugene/src/license/THIRD-PARTY.properties 2012-05-28 09:05:31 UTC (rev 1147)
@@ -13,13 +13,14 @@
# - MIT License
# - Mozilla Public License Version 1.0
# - The Apache Software License, Version 2.0
-# - http://jaxen.codehaus.org/license.html
+# - The SAX License
+# - The W3C License
+# - The Werken Company License
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Wed Jan 04 15:16:55 CET 2012
+#Mon May 28 11:02:25 CEST 2012
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
dom4j--dom4j--1.6.1=BSD
-jaxen--jaxen--1.1.1=http\://jaxen.codehaus.org/license.html
jdom--jdom--1.0=The Apache Software License, Version 2.0
1
0
Author: tchemit
Date: 2012-05-28 10:48:30 +0200 (Mon, 28 May 2012)
New Revision: 1146
Url: http://nuiton.org/repositories/revision/eugene/1146
Log:
still updates some dependencies
Modified:
trunk/pom.xml
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-05-28 08:32:18 UTC (rev 1145)
+++ trunk/pom.xml 2012-05-28 08:48:30 UTC (rev 1146)
@@ -373,13 +373,14 @@
<!-- pour un muli module on doit fixer le projectId -->
<projectId>eugene</projectId>
- <processorPluginVersion>1.2.1</processorPluginVersion>
- <nuitonUtilsVersion>2.4</nuitonUtilsVersion>
- <nuitonI18nVersion>2.4</nuitonI18nVersion>
+ <processorPluginVersion>1.2.2</processorPluginVersion>
+ <nuitonUtilsVersion>2.4.8</nuitonUtilsVersion>
+ <nuitonI18nVersion>2.4.1</nuitonI18nVersion>
<!-- TODO Move this back to mavenpom -->
- <antVersion>1.8.3</antVersion>
+ <antVersion>1.8.4</antVersion>
+ <jrstPluginVersion>1.5</jrstPluginVersion>
<!--Multilanguage maven-site -->
<locales>en,fr</locales>
1
0
Author: tchemit
Date: 2012-05-28 10:32:18 +0200 (Mon, 28 May 2012)
New Revision: 1145
Url: http://nuiton.org/repositories/revision/eugene/1145
Log:
updates some libs
fixes site links
Modified:
trunk/pom.xml
trunk/src/site/rst/index.rst
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-05-28 08:19:42 UTC (rev 1144)
+++ trunk/pom.xml 2012-05-28 08:32:18 UTC (rev 1145)
@@ -72,7 +72,7 @@
<dependency>
<groupId>xerces</groupId>
<artifactId>xercesImpl</artifactId>
- <version>2.9.1</version>
+ <version>2.10.0</version>
<scope>runtime</scope>
<exclusions>
<exclusion>
@@ -111,14 +111,14 @@
<dependency>
<groupId>xml-apis</groupId>
<artifactId>xml-apis</artifactId>
- <version>1.0.b2</version>
+ <version>1.4.01</version>
</dependency>
<!-- dom4j dep -->
<dependency>
<groupId>jaxen</groupId>
<artifactId>jaxen</artifactId>
- <version>1.1.1</version>
+ <version>1.1.3</version>
<scope>runtime</scope>
<exclusions>
<exclusion>
@@ -374,9 +374,13 @@
<projectId>eugene</projectId>
<processorPluginVersion>1.2.1</processorPluginVersion>
- <nuitonUtilsVersion>2.3</nuitonUtilsVersion>
- <nuitonI18nVersion>2.3.2</nuitonI18nVersion>
+ <nuitonUtilsVersion>2.4</nuitonUtilsVersion>
+ <nuitonI18nVersion>2.4</nuitonI18nVersion>
+
+ <!-- TODO Move this back to mavenpom -->
+ <antVersion>1.8.3</antVersion>
+
<!--Multilanguage maven-site -->
<locales>en,fr</locales>
Modified: trunk/src/site/rst/index.rst
===================================================================
--- trunk/src/site/rst/index.rst 2012-05-28 08:19:42 UTC (rev 1144)
+++ trunk/src/site/rst/index.rst 2012-05-28 08:32:18 UTC (rev 1145)
@@ -56,9 +56,9 @@
* `ant-eugene-task`_
* `maven-eugene-plugin`_
-.. _eugene-api: eugene/fr/index.html
-.. _ant-eugene-task: ant-eugene-task/fr/index.html
-.. _maven-eugene-plugin: maven-eugene-plugin/fr/index.html
+.. _eugene-api: eugene/index.html
+.. _ant-eugene-task: ant-eugene-task/index.html
+.. _maven-eugene-plugin: maven-eugene-plugin/index.html
More info on the project on `nuiton's forge`_ .
1
0
r1144 - in trunk: . ant-eugene-task/src/site eugene/src/site maven-eugene-plugin/src/site src/site src/site/resources src/site/resources/images src/site/resources/images/logos
by tchemit@users.nuiton.org 28 May '12
by tchemit@users.nuiton.org 28 May '12
28 May '12
Author: tchemit
Date: 2012-05-28 10:19:42 +0200 (Mon, 28 May 2012)
New Revision: 1144
Url: http://nuiton.org/repositories/revision/eugene/1144
Log:
fixes T?\195?\162che #2109: Updates to mavenpom 3.3.2
fixes T?\195?\162che #2110: Migrate site to fluido
Added:
trunk/src/site/resources/images/
trunk/src/site/resources/images/logos/
trunk/src/site/resources/images/logos/jrst-logo.png
trunk/src/site/resources/images/logos/restructuredtext-logo.png
Modified:
trunk/ant-eugene-task/src/site/site_en.xml
trunk/ant-eugene-task/src/site/site_fr.xml
trunk/eugene/src/site/site_en.xml
trunk/eugene/src/site/site_fr.xml
trunk/maven-eugene-plugin/src/site/site_en.xml
trunk/maven-eugene-plugin/src/site/site_fr.xml
trunk/pom.xml
trunk/src/site/site_en.xml
trunk/src/site/site_fr.xml
Modified: trunk/ant-eugene-task/src/site/site_en.xml
===================================================================
--- trunk/ant-eugene-task/src/site/site_en.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/ant-eugene-task/src/site/site_en.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -70,5 +70,23 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
</body>
</project>
Modified: trunk/ant-eugene-task/src/site/site_fr.xml
===================================================================
--- trunk/ant-eugene-task/src/site/site_fr.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/ant-eugene-task/src/site/site_fr.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -74,5 +74,24 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
+
</body>
</project>
Modified: trunk/eugene/src/site/site_en.xml
===================================================================
--- trunk/eugene/src/site/site_en.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/eugene/src/site/site_en.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -71,5 +71,24 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
+
</body>
</project>
Modified: trunk/eugene/src/site/site_fr.xml
===================================================================
--- trunk/eugene/src/site/site_fr.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/eugene/src/site/site_fr.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -83,5 +83,24 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
+
</body>
</project>
Modified: trunk/maven-eugene-plugin/src/site/site_en.xml
===================================================================
--- trunk/maven-eugene-plugin/src/site/site_en.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/maven-eugene-plugin/src/site/site_en.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -70,5 +70,24 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
+
</body>
</project>
Modified: trunk/maven-eugene-plugin/src/site/site_fr.xml
===================================================================
--- trunk/maven-eugene-plugin/src/site/site_fr.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/maven-eugene-plugin/src/site/site_fr.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -74,5 +74,24 @@
<menu ref="reports"/>
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
+
</body>
</project>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/pom.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -32,7 +32,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>mavenpom4redmineAndCentral</artifactId>
- <version>3.2</version>
+ <version>3.3.2</version>
</parent>
<artifactId>eugene</artifactId>
@@ -464,6 +464,35 @@
</property>
</activation>
+ <reporting>
+ <plugins>
+
+ <plugin>
+ <artifactId>maven-project-info-reports-plugin</artifactId>
+ <version>${projectInfoReportsPluginVersion}</version>
+ <reportSets>
+ <reportSet>
+ <reports>
+ <report>project-team</report>
+ <report>mailing-list</report>
+ <report>cim</report>
+ <report>issue-tracking</report>
+ <report>license</report>
+ <report>scm</report>
+ <report>dependencies</report>
+ <report>dependency-convergence</report>
+ <report>plugin-management</report>
+ <report>plugins</report>
+ <report>dependency-management</report>
+ <report>summary</report>
+ </reports>
+ </reportSet>
+ </reportSets>
+ </plugin>
+
+ </plugins>
+ </reporting>
+
<build>
<plugins>
<plugin>
Added: trunk/src/site/resources/images/logos/jrst-logo.png
===================================================================
(Binary files differ)
Property changes on: trunk/src/site/resources/images/logos/jrst-logo.png
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Added: trunk/src/site/resources/images/logos/restructuredtext-logo.png
===================================================================
(Binary files differ)
Property changes on: trunk/src/site/resources/images/logos/restructuredtext-logo.png
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Modified: trunk/src/site/site_en.xml
===================================================================
--- trunk/src/site/site_en.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/src/site/site_en.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -26,11 +26,35 @@
<project name="${project.name}">
+ <skin>
+ <groupId>org.apache.maven.skins</groupId>
+ <artifactId>maven-fluido-skin</artifactId>
+ <version>1.2.1</version>
+ </skin>
+
+ <custom>
+ <fluidoSkin>
+ <topBarEnabled>true</topBarEnabled>
+ <googleSearch/>
+ <sideBarEnabled>false</sideBarEnabled>
+ <searchEnabled>true</searchEnabled>
+ <sourceLineNumbersEnabled>true</sourceLineNumbersEnabled>
+ </fluidoSkin>
+ </custom>
+
<bannerLeft>
<name>${project.name}</name>
- <href>/</href>
+ <href>index.html</href>
</bannerLeft>
+ <bannerRight>
+ <src>http://www.codelutin.com/images/lutinorange-codelutin.png</src>
+ <href>http://www.codelutin.com</href>
+ </bannerRight>
+
+ <publishDate position="right" />
+ <version position="right" />
+
<poweredBy>
<logo href="http://maven.apache.org" name="Maven" img="${project.url}/images/logos/maven-feather.png"/>
<logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/jrst-logo.png"/>
@@ -77,5 +101,24 @@
<menu ref="modules"/>
<menu ref="reports"/>
+
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
</body>
</project>
Modified: trunk/src/site/site_fr.xml
===================================================================
--- trunk/src/site/site_fr.xml 2012-05-23 12:44:33 UTC (rev 1143)
+++ trunk/src/site/site_fr.xml 2012-05-28 08:19:42 UTC (rev 1144)
@@ -26,11 +26,35 @@
<project name="${project.name}">
+ <skin>
+ <groupId>org.apache.maven.skins</groupId>
+ <artifactId>maven-fluido-skin</artifactId>
+ <version>1.2.1</version>
+ </skin>
+
+ <custom>
+ <fluidoSkin>
+ <topBarEnabled>true</topBarEnabled>
+ <googleSearch/>
+ <sideBarEnabled>false</sideBarEnabled>
+ <searchEnabled>true</searchEnabled>
+ <sourceLineNumbersEnabled>true</sourceLineNumbersEnabled>
+ </fluidoSkin>
+ </custom>
+
<bannerLeft>
<name>${project.name}</name>
- <href>/</href>
+ <href>index.html</href>
</bannerLeft>
+ <bannerRight>
+ <src>http://www.codelutin.com/images/lutinorange-codelutin.png</src>
+ <href>http://www.codelutin.com</href>
+ </bannerRight>
+
+ <publishDate position="right" />
+ <version position="right" />
+
<poweredBy>
<logo href="http://maven.apache.org" name="Maven" img="${project.url}/images/logos/maven-feather.png"/>
<logo href="http://maven-site.nuiton.org/jrst/" name="JRst" img="${project.url}/images/jrst-logo.png"/>
@@ -83,5 +107,24 @@
</menu>
<menu ref="reports"/>
+
+ <footer>
+
+ <script type="text/javascript"
+ src="http://maven-site.nuiton.org/public/js/maven-site-nuiton.org.js">
+ </script>
+
+ <div id='projectMetas'
+ projectversion='${project.version}'
+ platform='${project.platform}'
+ projectid='${project.projectId}'
+ scm='${project.scm.url}'
+ scmwebeditorenabled='${project.scmwebeditorEnabled}'
+ scmwebeditorurl='${project.scmwebeditorUrl}'
+ siteSourcesType='${project.siteSourcesType}'
+ piwikEnabled='${project.piwikEnabled}'
+ piwikId='${project.piwikId}'>
+ </div>
+ </footer>
</body>
</project>
1
0
23 May '12
Author: tchemit
Date: 2012-05-23 14:44:33 +0200 (Wed, 23 May 2012)
New Revision: 1143
Url: http://nuiton.org/repositories/revision/eugene/1143
Log:
fixes #2102: Execution of maven plugin are not well isolated
Modified:
trunk/eugene/src/main/java/org/nuiton/eugene/Transformer.java
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/Transformer.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/Transformer.java 2012-05-11 09:21:27 UTC (rev 1142)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/Transformer.java 2012-05-23 12:44:33 UTC (rev 1143)
@@ -94,7 +94,8 @@
// build output template configuration
// merge input configuration + output properties
- Properties properties = getConfiguration().getProperties();
+ Properties properties =
+ new Properties(getConfiguration().getProperties());
properties.putAll(getOutputProperties());
TemplateConfiguration outconfig =
1
0
r1142 - in trunk: maven-eugene-plugin/src/site/fr/rst src/site/fr/rst src/site/rst
by ymartel@users.nuiton.org 11 May '12
by ymartel@users.nuiton.org 11 May '12
11 May '12
Author: ymartel
Date: 2012-05-11 11:21:27 +0200 (Fri, 11 May 2012)
New Revision: 1142
Url: http://nuiton.org/repositories/revision/eugene/1142
Log:
add some doc around zargo file renaming
Modified:
trunk/maven-eugene-plugin/src/site/fr/rst/usage.rst
trunk/src/site/fr/rst/08-FAQ.rst
trunk/src/site/rst/08-FAQ.rst
Modified: trunk/maven-eugene-plugin/src/site/fr/rst/usage.rst
===================================================================
--- trunk/maven-eugene-plugin/src/site/fr/rst/usage.rst 2012-03-29 09:46:06 UTC (rev 1141)
+++ trunk/maven-eugene-plugin/src/site/fr/rst/usage.rst 2012-05-11 09:21:27 UTC (rev 1142)
@@ -243,7 +243,7 @@
Phase zargo
~~~~~~~~~~~
-This phase permits to take some zargo files to extract form them the xmi files.
+Cette phase permet de prendre des fichiers zargo pour en extraire les fichiers xmi.
Example:
Modified: trunk/src/site/fr/rst/08-FAQ.rst
===================================================================
--- trunk/src/site/fr/rst/08-FAQ.rst 2012-03-29 09:46:06 UTC (rev 1141)
+++ trunk/src/site/fr/rst/08-FAQ.rst 2012-05-11 09:21:27 UTC (rev 1142)
@@ -78,3 +78,13 @@
.. _ToPIA: http://nuiton.org/projects/show/topia
.. _maven-eugene-plugin: ../maven-eugene-plugin/fr/index.html
+
+Pourquoi la génération ne marche plus après renommage des fichiers .zargo et properties
+=======================================================================================
+
+Lorsque l'on renomme les fichiers .zargo et .properties correspondant, les
+propriétés peuvent ne plus être prises en compte lors de la génération. En fait,
+le fichier .zargo est une archive qui contient plusieurs fichiers dont le
+fichier .xmi utilisé par la génération. Ce fichier n'est pas renommé avec le
+fichier .zargo et il est donc nécessaire d'éditer le fichier .zargo afin de
+synchroniser les noms de fichier qu'il contient.
\ No newline at end of file
Modified: trunk/src/site/rst/08-FAQ.rst
===================================================================
--- trunk/src/site/rst/08-FAQ.rst 2012-03-29 09:46:06 UTC (rev 1141)
+++ trunk/src/site/rst/08-FAQ.rst 2012-05-11 09:21:27 UTC (rev 1142)
@@ -81,3 +81,11 @@
.. _ToPIA: http://nuiton.org/projects/show/topia
.. _maven-eugene-plugin: maven-eugene-plugin/index.html
+
+Why properties are not taken during generation after renomming .zargo file ?
+============================================================================
+
+The .zargo file is an archive that contains some files, including .xmi file that
+is used in the xmi phase after zargo phase. But when we change .zargo file name,
+those included files are not renamed. The .zargo file must be edited to
+synchronized all its included files.
\ No newline at end of file
1
0
--- trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelBuilder.java 2012-05-28 10:13:34 UTC (rev 1150)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelBuilder.java 2012-05-31 14:58:52 UTC (rev 1151)
@@ -212,7 +212,7 @@
/**
* Add an attribute to a classifier (interface, class, enum).
* Modifiers allowed : STATIC, FINAL, PUBLIC, PRIVATE, PROTECTED, PACKAGE, ORDERED, UNIQUE.
* The last visibility set will be keeped.
*
* @param classifier where the attribute will be added
@@ -252,6 +252,9 @@
case UNIQUE:
attribute.setUnique(true);
break;
+ case TRANSIENT:
+ attribute.setTransient(true);
+ break;
default:
throw new IllegalArgumentException(
"Unsupported modifier type '" + modifier.name() + "'");
@@ -212,7 +212,7 @@
/**
* Add an attribute to a classifier (interface, class, enum).
- * Modifiers allowed : STATIC, FINAL, PUBLIC, PRIVATE, PROTECTED, PACKAGE, ORDERED, UNIQUE.
+ * Modifiers allowed : STATIC, FINAL, TRANSIENT, PUBLIC, PRIVATE, PROTECTED, PACKAGE, ORDERED, UNIQUE.
* The last visibility set will be keeped.
*
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/models/object/ObjectModelModifier.java
===================================================================